//  W2IController.m
//  www2image
//
//  Created by Daniel Stodle on 04/11/2008.
//  Copyright 2008-2009 Stodle Computer Software and Consulting. All rights reserved.
//
/*	www2image is licensed under the BSD license:
	
	Copyright (c) 2008-2009, Daniel Stoedle <daniel@scsc.no>,
	Stodle Computer Software and Consulting. All rights reserved.
	
	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions are met:

	- Redistributions of source code must retain the above copyright notice,
	  this list of conditions and the following disclaimer.

	- Redistributions in binary form must reproduce the above copyright notice,
	  this list of conditions and the following disclaimer in the documentation
	  and/or other materials provided with the distribution.

	- Neither the name of the Stodle Computer Software and Consulting nor the
	  names of its contributors may be used to endorse or promote products
	  derived from this software without specific prior written permission.

	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
	AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
	IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
	ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
	LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
	CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
	SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
	INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
	CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
	ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
	POSSIBILITY OF SUCH DAMAGE.
		
	Contacting the author:
	You can get in touch with me, Daniel Stødle (that's the Norwegian letter oe,
	in case your text editor didn't realize), here: <daniel@scsc.no>
	
	Note that the source code is best viewed with tabs set to 4 spaces.
	
	Version history:
	1.0 - 25. Feb 2009: Initial release.
*/


#import "W2IController.h"


@implementation W2IController

- (void)fetchURL:(const char*)url andStore:(const char*)path {
	NSRect		frame = NSMakeRect(0.f, 0.f, 768., 1024.0);
	
	[[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(urlLoaded:) name:WebViewProgressFinishedNotification object:0];
	_webView	= [[WebView alloc] initWithFrame:frame];
	[[_webView mainFrame] loadRequest:[NSURLRequest requestWithURL:[NSURL URLWithString:[NSString stringWithCString:url]]]];
	_path		= strdup(path);
}


- (void)urlLoaded:(NSNotification*)notif {
	//	Get the bounds for the entire thing
	NSRect					r;
	NSBitmapImageRep		*bmRep;
	CGImageRef				img;
	CFDictionaryRef			img_properties;
	CFMutableDataRef		compressed_data;
	CGImageDestinationRef	img_dst;
	float					quality = 0.8;
	int						depth	= 32;
	const void				*keys[2] = { kCGImageDestinationLossyCompressionQuality, kCGImagePropertyDepth };
	const void				*values[2]	= { CFNumberCreate(0, kCFNumberFloatType, &quality), CFNumberCreate(0, kCFNumberIntType, &depth) };
	FILE					*fd;
	NSScrollView			*scrollView;
	
	scrollView	= [[[[_webView mainFrame] frameView] documentView] enclosingScrollView];
	[scrollView setHasVerticalScroller:NO];
	[scrollView setHasHorizontalScroller:NO];
	r	= [[[[_webView mainFrame] frameView] documentView] bounds];
	[_webView setFrame:r];
//	printf("Page loaded; %p %p\n", [_webView enclosingScrollView], [[[[_webView mainFrame] frameView] documentView] enclosingScrollView]);
	printf("Bounds: %f %f %f %f\n", r.origin.x, r.origin.y, r.size.width, r.size.height);
//	printf("Bounds: %f %f %f %f\n", r2.origin.x, r2.origin.y, r2.size.width, r2.size.height);
	img_properties	= CFDictionaryCreate(0, keys, values, 1, &kCFTypeDictionaryKeyCallBacks, &kCFTypeDictionaryValueCallBacks);
	bmRep	= [_webView bitmapImageRepForCachingDisplayInRect:r];
	[_webView cacheDisplayInRect:r toBitmapImageRep:bmRep];
	
	img			= [bmRep CGImage];
	compressed_data	= CFDataCreateMutable(0, 0);
	img_dst			= CGImageDestinationCreateWithData(compressed_data, kUTTypeJPEG /* kUTTypePNG */, 1, 0);
	CGImageDestinationAddImage(img_dst, img, img_properties);
	CGImageDestinationFinalize(img_dst);
	CFRelease(img_dst);
	
	fd	= fopen(_path, "w");
	fwrite(CFDataGetBytePtr(compressed_data), CFDataGetLength(compressed_data), 1, fd);
	fclose(fd);
	[NSApp terminate:self];
}
@end
