//  main.m
//  www2image
//
//  Created by Daniel Stodle on 04/11/2008.
//  Copyright 2008-2009 Stodle Computer Software and Consulting. All rights reserved.
//
/*	www2image is licensed under the BSD license:
	
	Copyright (c) 2008-2009, Daniel Stoedle <daniel@scsc.no>,
	Stodle Computer Software and Consulting. All rights reserved.
	
	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions are met:

	- Redistributions of source code must retain the above copyright notice,
	  this list of conditions and the following disclaimer.

	- Redistributions in binary form must reproduce the above copyright notice,
	  this list of conditions and the following disclaimer in the documentation
	  and/or other materials provided with the distribution.

	- Neither the name of the Stodle Computer Software and Consulting nor the
	  names of its contributors may be used to endorse or promote products
	  derived from this software without specific prior written permission.

	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
	AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
	IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
	ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
	LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
	CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
	SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
	INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
	CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
	ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
	POSSIBILITY OF SUCH DAMAGE.
		
	Contacting the author:
	You can get in touch with me, Daniel Stødle (that's the Norwegian letter oe,
	in case your text editor didn't realize), here: <daniel@scsc.no>
	
	Note that the source code is best viewed with tabs set to 4 spaces.
*/

#import		<Cocoa/Cocoa.h>
#import		"W2IController.h"
#include	<unistd.h>
#include	<sys/types.h>
#include	<errno.h>
#include	<signal.h>
#include	<stdio.h>

void	usage(const char *name);

enum {
	kArg_unknown	= -1,
	kSet_url_arg,
	kSet_output_arg,
};

int main (int argc, const char * argv[]) {
	NSAutoreleasePool		*pool	= [[NSAutoreleasePool alloc] init];
	W2IController			*ctrl;
	int						i, arg = kArg_unknown;
	const char				*url = 0,
							*output = "./output.jpg";
	
	for (i=1;i<argc;i++) {
		if (strcmp(argv[i], "-u") == 0)
			arg	= kSet_url_arg;
		else if (strcmp(argv[i], "-o") == 0)
			arg	= kSet_output_arg;
		else if (strcmp(argv[i], "-h") == 0 || strcmp(argv[i], "-help") == 0) {
			usage(argv[0]);
			return 0;
		}
		else {
			switch (arg) {
				case kSet_url_arg:
					url	= argv[i];
					break;
				case kSet_output_arg:
					output	= argv[i];
					break;
				default:
					usage(argv[0]);
					return 0;
			}
			arg	= kArg_unknown;
		}
	}
	if (!url || !output || arg != kArg_unknown) {
		usage(argv[0]);
		return -1;
	}
	[NSApplication sharedApplication];
	ctrl	= [[W2IController alloc] init];
	[ctrl fetchURL:url andStore:output];
	[NSApp run];
	[pool release];
	return 0;
}

void	usage(const char *name) {
	printf("Usage: %s <-u url> [-o output image] [-h,-help]\n", name);
	printf(" -h, -help: Print this info.\n");
	printf(" -u url: The URL to render\n");
	printf(" -o output: The name of the image to save the rendering to.\n");
	printf("            Default value is './output.jpg'.\n");
}
